==> blancoNLpackGenerator-0.0.94-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/resourcebundle/BlancoNLpackGeneratorResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.nlpack.generator.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoNLpackGenerator]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoNLpackGeneratorResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoNLpackGeneratorResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGenerator]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoNLpackGeneratorResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoNLpackGenerator");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGenerator]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoNLpackGeneratorResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoNLpackGenerator", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGenerator]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoNLpackGeneratorResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoNLpackGenerator", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoNLpackGenerator], key[TARGET_LOCALE]
     *
     * [ja] (ja)<br>
     *
     * @return key[TARGET_LOCALE]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getTargetLocale() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "ja";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("TARGET_LOCALE");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoNLpackGenerator], key[PROPERTIES_HEADER]
     *
     * [# initial generation - blancoNLpackGenerator and Pleiades.] (ja)<br>
     *
     * @return key[PROPERTIES_HEADER]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getPropertiesHeader() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "# initial generation - blancoNLpackGenerator and Pleiades.";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("PROPERTIES_HEADER");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}

==> blancoNLpackGenerator-0.1.21-src.zip: blancoNLpackGenerator/blanco/main/blanco/nlpack/generator/resourcebundle/BlancoNLpackGeneratorResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.nlpack.generator.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoNLpackGenerator]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoNLpackGeneratorResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoNLpackGeneratorResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGenerator]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoNLpackGeneratorResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/nlpack/generator/resourcebundle/BlancoNLpackGenerator");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGenerator]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoNLpackGeneratorResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/nlpack/generator/resourcebundle/BlancoNLpackGenerator", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGenerator]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoNLpackGeneratorResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/nlpack/generator/resourcebundle/BlancoNLpackGenerator", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoNLpackGenerator], key[TARGET_LOCALE]
     *
     * [ja] (ja)<br>
     *
     * @return key[TARGET_LOCALE]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getTargetLocale() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "ja";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("TARGET_LOCALE");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoNLpackGenerator], key[PROPERTIES_HEADER]
     *
     * [# initial generation - blancoNLpackGenerator and Pleiades.] (ja)<br>
     *
     * @return key[PROPERTIES_HEADER]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getPropertiesHeader() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "# initial generation - blancoNLpackGenerator and Pleiades.";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("PROPERTIES_HEADER");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}
